@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -66,16 +66,30 @@ extern "C" {
     cut_test_fail(FAILURE, NULL, format, ## __VA_ARGS__)
 
 /**
- * cut_pending:
+ * cut_pend:
  * @format: the message format. See the printf() documentation.
  * @...: the parameters to insert into the format string.
  *
  * Marks the test is pending with message. The test is
  * stopped.
  */
-#define cut_pending(format, ...)                 \
+#define cut_pend(format, ...)                               \
     cut_test_fail(PENDING, NULL, format, ## __VA_ARGS__)
 
+#ifndef CUTTER_DISABLE_DEPRECATED
+/**
+ * cut_pending:
+ * @format: the message format. See the printf() documentation.
+ * @...: the parameters to insert into the format string.
+ *
+ * Marks the test is pending with message. The test is
+ * stopped.
+ *
+ * Deprecated: 0.4: Use cut_pend() instead.
+ */
+#define cut_pending(format, ...) cut_pend(format, ## __VA_ARGS__)
+#endif
+
 /**
  * cut_notify:
  * @format: the message format. See the printf() documentation.
@@ -251,7 +265,7 @@ extern "C" {
 /**
  * cut_assert_equal_string:
  * @expected: an expected string value.
- * @actual: an expected string value.
+ * @actual: an actual string value.
  * @...: optional format string, followed by parameters to insert
  * into the format string (as with printf())
  *
@@ -286,11 +300,28 @@ extern "C" {
     }                                                                   \
 } while(0)
 
+/**
+ * cut_assert_equal_string_with_free:
+ * @expected: an expected string value.
+ * @actual: an actual string value that is freed.
+ * @...: optional format string, followed by parameters to insert
+ * into the format string (as with printf())
+ *
+ * Passes if both @expected and @actual are NULL or
+ * strcmp(@expected, @actual) == 0.
+ *
+ * Since: 0.3
+ */
+#define cut_assert_equal_string_with_free(expected, actual, ...)        \
+    cut_assert_equal_string(expected,                                   \
+                            cut_take_string(actual),                    \
+                            ## __VA_ARGS__);
+
 #ifndef CUTTER_DISABLE_DEPRECATED
 /**
  * cut_assert_equal_string_or_null:
  * @expected: an expected string value.
- * @actual: an expected string value.
+ * @actual: an actual string value.
  * @...: optional format string, followed by parameters to insert
  * into the format string (as with printf())
  *
@@ -459,5 +490,5 @@ extern "C" {
 #endif /* __CUT_ASSERTIONS_H__ */
 
 /*
-vi:ts=4:nowrap:ai:expandtab:sw=4
+vi:nowrap:ai:expandtab:sw=4
 */
