@@ -5,6 +5,7 @@
 #include "cut-public.h"
 #include "cut-private.h"
 #include "cut-runner.h"
+#include "cut-listener.h"
 #include "cut-main.h"
 #include "cut-test.h"
 #include "cut-test-case.h"
@@ -13,7 +14,10 @@
 #include "cut-test-suite.h"
 #include "cut-test-result.h"
 #include "cut-ui.h"
-#include "cut-ui-factory.h"
+#include "cut-factory-builder.h"
+#include "cut-report-factory-builder.h"
+#include "cut-ui-factory-builder.h"
+#include "cut-module-factory.h"
 #include "cut-report.h"
 #include "cut-verbose-level.h"
 
