@@ -10,6 +10,8 @@ G_BEGIN_DECLS
 /* enumerations from "cut-public.h" */
 GType cut_test_result_status_get_type (void);
 #define CUT_TYPE_TEST_RESULT_STATUS (cut_test_result_status_get_type())
+GType cut_report_file_mode_get_type (void);
+#define CUT_TYPE_REPORT_FILE_MODE (cut_report_file_mode_get_type())
 GType cut_verbose_level_get_type (void);
 #define CUT_TYPE_VERBOSE_LEVEL (cut_verbose_level_get_type())
 GType cut_verbose_level_error_get_type (void);
