@@ -37,7 +37,7 @@
 #include "cut-runner.h"
 #include "cut-test-suite.h"
 #include "cut-ui.h"
-#include "cut-ui-factory.h"
+#include "cut-module-factory.h"
 #include "cut-value-equal.h"
 
 static gboolean initialized = FALSE;
@@ -46,10 +46,8 @@ static gchar *source_directory = NULL;
 static const gchar **test_case_names = NULL;
 static const gchar **test_names = NULL;
 static gboolean use_multi_thread = FALSE;
-static const gchar *ui_name = NULL;
 static gboolean _show_all_uis = FALSE;
-
-static CutUIFactory *factory = NULL;
+static GList *factories = NULL;
 
 static const GOptionEntry option_entries[] =
 {
@@ -61,8 +59,6 @@ static const GOptionEntry option_entries[] =
      N_("Specify test cases"), "TEST_CASE_NAME"},
     {"multi-thread", 'm', 0, G_OPTION_ARG_NONE, &use_multi_thread,
      N_("Run test cases with multi-thread"), NULL},
-    {"ui", 'u', 0, G_OPTION_ARG_STRING, &ui_name,
-     N_("Specify UI"), "[console|gtk]"},
     {"show-all-uis", 0, 0, G_OPTION_ARG_NONE, &_show_all_uis,
      N_("Show all available UIs and exit"), NULL},
     {NULL}
@@ -73,8 +69,7 @@ show_all_uis (void)
 {
     GList *names, *node;
 
-    cut_ui_factory_load(NULL);
-    names = cut_ui_factory_get_names();
+    names = cut_module_factory_get_names("ui");
     for (node = names; node; node = g_list_next(node)) {
         const gchar *name = node->data;
         if (g_list_next(node))
@@ -83,6 +78,7 @@ show_all_uis (void)
             g_print("%s", name);
     }
     g_print("\n");
+    g_list_foreach(names, (GFunc)g_free, NULL);
     g_list_free(names);
 }
 
@@ -120,20 +116,24 @@ cut_init (int *argc, char ***argv)
         exit(1);
     }
 
+    cut_module_factory_init();
+    cut_module_factory_load(NULL);
+    cut_module_factory_set_option_context(option_context);
     if (_show_all_uis) {
         show_all_uis();
         exit(1);
     }
 
-    cut_ui_factory_init();
-    if (!ui_name)
-        ui_name = "console";
-    factory = cut_ui_factory_new(ui_name, NULL);
-    if (!factory) {
-        g_warning("can't find specified UI: %s", ui_name);
+    g_option_context_set_help_enabled(option_context, TRUE);
+    g_option_context_set_ignore_unknown_options(option_context, TRUE);
+    if (!g_option_context_parse(option_context, argc, argv, &error)) {
+        g_print("%s\n", error->message);
+        g_error_free(error);
+        g_option_context_free(option_context);
         exit(1);
     }
-    cut_ui_factory_set_option_group(factory, option_context);
+
+    factories = cut_module_factory_build_factories();
 
     g_option_context_set_help_enabled(option_context, TRUE);
     g_option_context_set_ignore_unknown_options(option_context, FALSE);
@@ -175,12 +175,8 @@ cut_quit (void)
     if (!initialized)
         return;
 
-    if (factory)
-        g_object_unref(factory);
-    factory = NULL;
-
     cut_ui_quit();
-    cut_ui_factory_quit();
+    cut_module_factory_quit();
 
     initialized = FALSE;
 }
@@ -202,25 +198,60 @@ cut_create_runner (void)
     return runner;
 }
 
+static GList *
+create_listeners (void)
+{
+    GList *listeners = NULL, *node;
+
+    for (node = factories; node; node = g_list_next(node)) {
+        GObject *listener;
+        listener = cut_module_factory_create(CUT_MODULE_FACTORY(node->data));
+        listeners = g_list_prepend(listeners, listener);
+    }
+
+    return listeners;
+}
+
+static void
+add_listeners (CutRunner *runner, GList *listeners)
+{
+    GList *node;
+
+    for (node = listeners; node; node = g_list_next(node)) {
+        CutListener *listener = CUT_LISTENER(node->data);
+        cut_runner_add_listener(runner, listener);
+    }
+}
+
+static void
+remove_listeners (CutRunner *runner, GList *listeners)
+{
+    GList *node;
+
+    for (node = listeners; node; node = g_list_next(node)) {
+        CutListener *listener = CUT_LISTENER(node->data);
+        cut_runner_remove_listener(runner, listener);
+        g_object_unref(listener);
+    }
+}
+
 gboolean
 cut_run_runner (CutRunner *runner)
 {
-    CutUI *ui;
     gboolean success;
+    GList *listeners;
 
     if (!initialized) {
         g_warning("not initialized");
         return FALSE;
     }
 
-    ui = cut_ui_factory_create(factory);
-    if (!ui) {
-        g_warning("can't create UI: %s", ui_name);
-        return FALSE;
-    }
+    listeners = create_listeners();
+    add_listeners(runner, listeners);
+    success = cut_runner_run(runner);
+    remove_listeners(runner, listeners);
+    g_list_free(listeners);
 
-    success = cut_ui_run(ui, runner);
-    g_object_unref(ui);
     return success;
 }
 
@@ -238,5 +269,5 @@ cut_run (void)
 }
 
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
