@@ -23,8 +23,6 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <stdlib.h>
-#include <string.h>
 #include <glib.h>
 
 #include "cut-runner.h"
@@ -56,6 +54,7 @@ struct _CutRunnerPrivate
     gchar **target_test_names;
     gboolean canceled;
     CutTestSuite *test_suite;
+    GList *listeners;
 };
 
 enum
@@ -80,12 +79,12 @@ enum
     START_TEST_CASE,
     START_TEST,
 
-    PASS,
-    SUCCESS,
-    FAILURE,
-    ERROR,
-    PENDING,
-    NOTIFICATION,
+    PASS_TEST,
+    SUCCESS_TEST,
+    FAILURE_TEST,
+    ERROR_TEST,
+    PENDING_TEST,
+    NOTIFICATION_TEST,
 
     COMPLETE_TEST,
     COMPLETE_TEST_CASE,
@@ -165,7 +164,7 @@ cut_runner_class_init (CutRunnerClass *klass)
     g_object_class_install_property(gobject_class, PROP_USE_MULTI_THREAD, spec);
 
 
-	signals[READY_TEST_SUITE]
+    signals[READY_TEST_SUITE]
         = g_signal_new ("ready-test-suite",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
@@ -175,7 +174,7 @@ cut_runner_class_init (CutRunnerClass *klass)
                         G_TYPE_NONE, 3,
                         CUT_TYPE_TEST_SUITE, G_TYPE_UINT, G_TYPE_UINT);
 
-	signals[START_TEST_SUITE]
+    signals[START_TEST_SUITE]
         = g_signal_new ("start-test-suite",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
@@ -184,7 +183,7 @@ cut_runner_class_init (CutRunnerClass *klass)
                         g_cclosure_marshal_VOID__OBJECT,
                         G_TYPE_NONE, 1, CUT_TYPE_TEST_SUITE);
 
-	signals[READY_TEST_CASE]
+    signals[READY_TEST_CASE]
         = g_signal_new ("ready-test-case",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
@@ -193,7 +192,7 @@ cut_runner_class_init (CutRunnerClass *klass)
                         _cut_marshal_VOID__OBJECT_UINT,
                         G_TYPE_NONE, 2, CUT_TYPE_TEST_CASE, G_TYPE_UINT);
 
-	signals[START_TEST_CASE]
+    signals[START_TEST_CASE]
         = g_signal_new ("start-test-case",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
@@ -202,7 +201,7 @@ cut_runner_class_init (CutRunnerClass *klass)
                         g_cclosure_marshal_VOID__OBJECT,
                         G_TYPE_NONE, 1, CUT_TYPE_TEST_CASE);
 
-	signals[START_TEST]
+    signals[START_TEST]
         = g_signal_new ("start-test",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
@@ -211,62 +210,62 @@ cut_runner_class_init (CutRunnerClass *klass)
                         _cut_marshal_VOID__OBJECT_OBJECT,
                         G_TYPE_NONE, 2, CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT);
 
-	signals[PASS]
-        = g_signal_new ("pass",
+    signals[PASS_TEST]
+        = g_signal_new ("pass-test",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
-                        G_STRUCT_OFFSET (CutRunnerClass, pass),
+                        G_STRUCT_OFFSET (CutRunnerClass, pass_test),
                         NULL, NULL,
                         _cut_marshal_VOID__OBJECT_OBJECT,
                         G_TYPE_NONE, 2, CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT);
 
-	signals[SUCCESS]
-        = g_signal_new ("success",
+    signals[SUCCESS_TEST]
+        = g_signal_new ("success-test",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
-                        G_STRUCT_OFFSET (CutRunnerClass, success),
+                        G_STRUCT_OFFSET (CutRunnerClass, success_test),
                         NULL, NULL,
                         g_cclosure_marshal_VOID__OBJECT,
                         G_TYPE_NONE, 1, CUT_TYPE_TEST);
 
-	signals[FAILURE]
-        = g_signal_new ("failure",
+    signals[FAILURE_TEST]
+        = g_signal_new ("failure-test",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
-                        G_STRUCT_OFFSET (CutRunnerClass, failure),
+                        G_STRUCT_OFFSET (CutRunnerClass, failure_test),
                         NULL, NULL,
                         _cut_marshal_VOID__OBJECT_OBJECT_OBJECT,
                         G_TYPE_NONE, 3,
                         CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT,
                         CUT_TYPE_TEST_RESULT);
 
-	signals[ERROR]
-        = g_signal_new ("error",
+    signals[ERROR_TEST]
+        = g_signal_new ("error-test",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
-                        G_STRUCT_OFFSET (CutRunnerClass, error),
+                        G_STRUCT_OFFSET (CutRunnerClass, error_test),
                         NULL, NULL,
                         _cut_marshal_VOID__OBJECT_OBJECT_OBJECT,
                         G_TYPE_NONE, 3,
                         CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT,
                         CUT_TYPE_TEST_RESULT);
 
-	signals[PENDING]
-        = g_signal_new ("pending",
+    signals[PENDING_TEST]
+        = g_signal_new ("pending-test",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
-                        G_STRUCT_OFFSET (CutRunnerClass, pending),
+                        G_STRUCT_OFFSET (CutRunnerClass, pending_test),
                         NULL, NULL,
                         _cut_marshal_VOID__OBJECT_OBJECT_OBJECT,
                         G_TYPE_NONE, 3,
                         CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT,
                         CUT_TYPE_TEST_RESULT);
 
-	signals[NOTIFICATION]
-        = g_signal_new ("notification",
+    signals[NOTIFICATION_TEST]
+        = g_signal_new ("notification-test",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
-                        G_STRUCT_OFFSET (CutRunnerClass, notification),
+                        G_STRUCT_OFFSET (CutRunnerClass, notification_test),
                         NULL, NULL,
                         _cut_marshal_VOID__OBJECT_OBJECT_OBJECT,
                         G_TYPE_NONE, 3,
@@ -282,7 +281,7 @@ cut_runner_class_init (CutRunnerClass *klass)
                         _cut_marshal_VOID__OBJECT_OBJECT,
                         G_TYPE_NONE, 2, CUT_TYPE_TEST, CUT_TYPE_TEST_CONTEXT);
 
-	signals[COMPLETE_TEST_CASE]
+    signals[COMPLETE_TEST_CASE]
         = g_signal_new ("complete-test-case",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
@@ -291,7 +290,7 @@ cut_runner_class_init (CutRunnerClass *klass)
                         g_cclosure_marshal_VOID__OBJECT,
                         G_TYPE_NONE, 1, CUT_TYPE_TEST_CASE);
 
-	signals[COMPLETE_TEST_SUITE]
+    signals[COMPLETE_TEST_SUITE]
         = g_signal_new ("complete-test-suite",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
@@ -300,7 +299,7 @@ cut_runner_class_init (CutRunnerClass *klass)
                         g_cclosure_marshal_VOID__OBJECT,
                         G_TYPE_NONE, 1, CUT_TYPE_TEST_SUITE);
 
-	signals[CRASHED]
+    signals[CRASHED]
         = g_signal_new ("crashed",
                         G_TYPE_FROM_CLASS (klass),
                         G_SIGNAL_RUN_LAST,
@@ -334,6 +333,13 @@ cut_runner_init (CutRunner *runner)
     priv->target_test_names = NULL;
     priv->canceled = FALSE;
     priv->test_suite = NULL;
+    priv->listeners = NULL;
+}
+
+static void
+remove_listener (CutListener *listener, CutRunner *runner)
+{
+    cut_listener_detach_from_runner(listener, runner);
 }
 
 static void
@@ -357,6 +363,12 @@ dispose (GObject *object)
         priv->test_suite = NULL;
     }
 
+    if (priv->listeners) {
+        g_list_foreach(priv->listeners, (GFunc)remove_listener, CUT_RUNNER(object));
+        g_list_free(priv->listeners);
+        priv->listeners = NULL;
+    }
+
     g_free(priv->stack_trace);
     priv->stack_trace = NULL;
 
@@ -564,7 +576,7 @@ cb_pass_assertion (CutTest *test, CutTestContext *test_context, gpointer data)
     priv->n_assertions++;
     g_mutex_unlock(priv->mutex);
 
-    g_signal_emit(runner, signals[PASS], 0, test, test_context);
+    g_signal_emit(runner, signals[PASS_TEST], 0, test, test_context);
 }
 
 static void
@@ -578,7 +590,7 @@ cb_success (CutTest *test, CutTestResult *result, gpointer data)
     priv->results = g_list_prepend(priv->results, g_object_ref(result));
     g_mutex_unlock(priv->mutex);
 
-    g_signal_emit(runner, signals[SUCCESS], 0, test);
+    g_signal_emit(runner, signals[SUCCESS_TEST], 0, test);
 }
 
 static void
@@ -594,7 +606,7 @@ cb_failure (CutTest *test, CutTestContext *test_context, CutTestResult *result,
     priv->n_failures++;
     g_mutex_unlock(priv->mutex);
 
-    g_signal_emit(runner, signals[FAILURE], 0, test, test_context, result);
+    g_signal_emit(runner, signals[FAILURE_TEST], 0, test, test_context, result);
 }
 
 static void
@@ -610,7 +622,7 @@ cb_error (CutTest *test, CutTestContext *test_context, CutTestResult *result,
     priv->n_errors++;
     g_mutex_unlock(priv->mutex);
 
-    g_signal_emit(runner, signals[ERROR], 0, test, test_context, result);
+    g_signal_emit(runner, signals[ERROR_TEST], 0, test, test_context, result);
 }
 
 static void
@@ -626,7 +638,7 @@ cb_pending (CutTest *test, CutTestContext *test_context, CutTestResult *result,
     priv->n_pendings++;
     g_mutex_unlock(priv->mutex);
 
-    g_signal_emit(runner, signals[PENDING], 0, test, test_context, result);
+    g_signal_emit(runner, signals[PENDING_TEST], 0, test, test_context, result);
 }
 
 static void
@@ -642,7 +654,7 @@ cb_notification (CutTest *test, CutTestContext *test_context,
     priv->n_notifications++;
     g_mutex_unlock(priv->mutex);
 
-    g_signal_emit(runner, signals[NOTIFICATION], 0, test, test_context, result);
+    g_signal_emit(runner, signals[NOTIFICATION_TEST], 0, test, test_context, result);
 }
 
 static void
@@ -958,15 +970,83 @@ cut_runner_set_test_suite (CutRunner *runner, CutTestSuite *suite)
     priv->test_suite = suite;
 }
 
+static void
+attach_listener (CutListener *listener, CutRunner *runner)
+{
+    cut_listener_attach_to_runner(listener, runner);
+}
+
+static void
+attach_all_listeners (CutRunner *runner)
+{
+    CutRunnerPrivate *priv = CUT_RUNNER_GET_PRIVATE(runner);
+
+    g_list_foreach(priv->listeners, (GFunc)attach_listener, runner);
+}
+
+static void
+detach_listener (CutListener *listener, CutRunner *runner)
+{
+    cut_listener_detach_from_runner(listener, runner);
+}
+
+static void
+detach_all_listeners (CutRunner *runner)
+{
+    CutRunnerPrivate *priv = CUT_RUNNER_GET_PRIVATE(runner);
+
+    g_list_foreach(priv->listeners, (GFunc)detach_listener, runner);
+}
+
 gboolean
 cut_runner_run (CutRunner *runner)
 {
     CutTestSuite *suite;
+    gboolean success;
 
     suite = cut_runner_get_test_suite(runner);
-    return cut_test_suite_run(suite, runner);
+    attach_all_listeners(runner);
+    success = cut_test_suite_run(suite, runner);
+    detach_all_listeners(runner);
+
+    return success;
+}
+
+void
+cut_runner_add_listener (CutRunner *runner,
+                         CutListener *listener)
+{
+    CutRunnerPrivate *priv = CUT_RUNNER_GET_PRIVATE(runner);
+
+    priv->listeners = g_list_prepend(priv->listeners, g_object_ref(listener));
+}
+
+void
+cut_runner_remove_listener (CutRunner *runner, CutListener *listener)
+{
+    CutRunnerPrivate *priv = CUT_RUNNER_GET_PRIVATE(runner);
+    remove_listener(listener, runner);
+    priv->listeners = g_list_remove(priv->listeners, listener);
+    g_object_unref(listener);
+}
+
+gchar *
+cut_runner_build_source_filename (CutRunner *runner, const gchar *filename)
+{
+    const gchar *source_directory;
+    gchar *source_filename;
+
+    source_directory = cut_runner_get_source_directory(runner);
+    if (source_directory) {
+        source_filename = g_build_filename(source_directory,
+                                           filename,
+                                           NULL);
+    } else {
+        source_filename = g_strdup(filename);
+    }
+    return source_filename;
 }
 
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
