@@ -25,7 +25,7 @@
 #include <glib-object.h>
 
 #include <cutter/cut-test-suite.h>
-#include <cutter/cut-verbose-level.h>
+#include <cutter/cut-listener.h>
 
 G_BEGIN_DECLS
 
@@ -62,24 +62,24 @@ struct _CutRunnerClass
                                  CutTest        *test,
                                  CutTestContext *test_context);
 
-    void (*pass)                (CutRunner      *runner,
+    void (*pass_test)           (CutRunner      *runner,
                                  CutTest        *test,
                                  CutTestContext *test_context);
-    void (*success)             (CutRunner      *runner,
+    void (*success_test)        (CutRunner      *runner,
                                  CutTest        *test);
-    void (*failure)             (CutRunner      *runner,
+    void (*failure_test)        (CutRunner      *runner,
                                  CutTest        *test,
                                  CutTestContext *test_context,
                                  CutTestResult  *result);
-    void (*error)               (CutRunner      *runner,
+    void (*error_test)          (CutRunner      *runner,
                                  CutTest        *test,
                                  CutTestContext *test_context,
                                  CutTestResult  *result);
-    void (*pending)             (CutRunner      *runner,
+    void (*pending_test)        (CutRunner      *runner,
                                  CutTest        *test,
                                  CutTestContext *test_context,
                                  CutTestResult  *result);
-    void (*notification)        (CutRunner      *runner,
+    void (*notification_test)   (CutRunner      *runner,
                                  CutTest        *test,
                                  CutTestContext *test_context,
                                  CutTestResult  *result);
@@ -148,11 +148,19 @@ void          cut_runner_set_test_suite            (CutRunner *runner,
                                                     CutTestSuite *suite);
 gboolean      cut_runner_run                       (CutRunner *runner);
 
+void          cut_runner_add_listener              (CutRunner   *runner,
+                                                    CutListener *listener);
+void          cut_runner_remove_listener           (CutRunner   *runner,
+                                                    CutListener *listener);
+
+gchar        *cut_runner_build_source_filename     (CutRunner *runner,
+                                                    const gchar *filename);
+
 
 G_END_DECLS
 
 #endif /* __CUT_RUNNER_H__ */
 
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
