@@ -40,21 +40,23 @@
 typedef struct _CutTestCasePrivate	CutTestCasePrivate;
 struct _CutTestCasePrivate
 {
-    gchar *name;
     CutSetupFunction setup;
     CutTearDownFunction teardown;
     CutGetCurrentTestContextFunction get_current_test_context;
     CutSetCurrentTestContextFunction set_current_test_context;
+    CutInitializeFunction initialize;
+    CutFinalizeFunction finalize;
 };
 
 enum
 {
     PROP_0,
-    PROP_NAME,
     PROP_SETUP_FUNCTION,
     PROP_TEAR_DOWN_FUNCTION,
     PROP_GET_CURRENT_TEST_CONTEXT_FUNCTION,
-    PROP_SET_CURRENT_TEST_CONTEXT_FUNCTION
+    PROP_SET_CURRENT_TEST_CONTEXT_FUNCTION,
+    PROP_INITIALIZE_FUNCTION,
+    PROP_FINALIZE_FUNCTION
 };
 
 enum
@@ -79,8 +81,6 @@ static void get_property   (GObject         *object,
                             GValue          *value,
                             GParamSpec      *pspec);
 
-static const gchar *real_get_name     (CutTest  *test);
-
 static void
 cut_test_case_class_init (CutTestCaseClass *klass)
 {
@@ -95,15 +95,6 @@ cut_test_case_class_init (CutTestCaseClass *klass)
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
 
-    test_class->get_name = real_get_name;
-
-    spec = g_param_spec_string("name",
-                               "name",
-                               "The name of the test case",
-                               NULL,
-                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
-    g_object_class_install_property(gobject_class, PROP_NAME, spec);
-
     spec = g_param_spec_pointer("setup-function",
                                 "Setup Function",
                                 "The function for setup",
@@ -132,6 +123,22 @@ cut_test_case_class_init (CutTestCaseClass *klass)
                                     PROP_SET_CURRENT_TEST_CONTEXT_FUNCTION,
                                     spec);
 
+    spec = g_param_spec_pointer("initialize-function",
+                                "Initialize Function",
+                                "The function for initialization of TestCase",
+                                G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+    g_object_class_install_property(gobject_class,
+                                    PROP_INITIALIZE_FUNCTION,
+                                    spec);
+
+    spec = g_param_spec_pointer("finalize-function",
+                                "Finalize Function",
+                                "The function for finalization of TestCase",
+                                G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+    g_object_class_install_property(gobject_class,
+                                    PROP_FINALIZE_FUNCTION,
+                                    spec);
+
 
     cut_test_case_signals[READY_SIGNAL]
         = g_signal_new("ready",
@@ -172,19 +179,13 @@ cut_test_case_init (CutTestCase *test_case)
     priv->teardown = NULL;
     priv->get_current_test_context = NULL;
     priv->set_current_test_context = NULL;
-    priv->name = NULL;
+    priv->initialize = NULL;
+    priv->finalize = NULL;
 }
 
 static void
 dispose (GObject *object)
 {
-    CutTestCasePrivate *priv = CUT_TEST_CASE_GET_PRIVATE(object);
-
-    if (priv->name) {
-        g_free(priv->name);
-        priv->name = NULL;
-    }
-
     G_OBJECT_CLASS(cut_test_case_parent_class)->dispose(object);
 }
 
@@ -197,11 +198,6 @@ set_property (GObject      *object,
     CutTestCasePrivate *priv = CUT_TEST_CASE_GET_PRIVATE(object);
 
     switch (prop_id) {
-      case PROP_NAME:
-        if (priv->name)
-            g_free(priv->name);
-        priv->name = g_value_dup_string(value);
-        break;
       case PROP_SETUP_FUNCTION:
         priv->setup = g_value_get_pointer(value);
         break;
@@ -214,6 +210,12 @@ set_property (GObject      *object,
       case PROP_SET_CURRENT_TEST_CONTEXT_FUNCTION:
         priv->set_current_test_context = g_value_get_pointer(value);
         break;
+      case PROP_INITIALIZE_FUNCTION:
+        priv->initialize = g_value_get_pointer(value);
+        break;
+      case PROP_FINALIZE_FUNCTION:
+        priv->finalize = g_value_get_pointer(value);
+        break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -229,20 +231,17 @@ get_property (GObject    *object,
     CutTestCasePrivate *priv = CUT_TEST_CASE_GET_PRIVATE(object);
 
     switch (prop_id) {
-      case PROP_NAME:
-        g_value_set_string(value, priv->name);
-        break;
       case PROP_SETUP_FUNCTION:
         g_value_set_pointer(value, priv->setup);
         break;
       case PROP_TEAR_DOWN_FUNCTION:
         g_value_set_pointer(value, priv->teardown);
         break;
-      case PROP_GET_CURRENT_TEST_CONTEXT_FUNCTION:
-        g_value_set_pointer(value, priv->get_current_test_context);
+      case PROP_INITIALIZE_FUNCTION:
+        g_value_set_pointer(value, priv->initialize);
         break;
-      case PROP_SET_CURRENT_TEST_CONTEXT_FUNCTION:
-        g_value_set_pointer(value, priv->set_current_test_context);
+      case PROP_FINALIZE_FUNCTION:
+        g_value_set_pointer(value, priv->finalize);
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -255,7 +254,9 @@ cut_test_case_new (const gchar *name,
                    CutSetupFunction setup_function,
                    CutTearDownFunction teardown_function,
                    CutGetCurrentTestContextFunction get_current_test_context_function,
-                   CutSetCurrentTestContextFunction set_current_test_context_function)
+                   CutSetCurrentTestContextFunction set_current_test_context_function,
+                   CutInitializeFunction initialize_function,
+                   CutFinalizeFunction finalize_function)
 {
     return g_object_new(CUT_TYPE_TEST_CASE,
                         "name", name,
@@ -265,6 +266,8 @@ cut_test_case_new (const gchar *name,
                         get_current_test_context_function,
                         "set-current-test-context-function",
                         set_current_test_context_function,
+                        "initialize-function", initialize_function,
+                        "finalize-function", finalize_function,
                         NULL);
 }
 
@@ -295,12 +298,6 @@ cut_test_case_get_n_tests (CutTestCase *test_case, const gchar **test_names)
     return n_tests;
 }
 
-static const gchar *
-real_get_name (CutTest *test)
-{
-    return CUT_TEST_CASE_GET_PRIVATE(test)->name;
-}
-
 void
 cut_test_case_add_test (CutTestCase *test_case, CutTest *test)
 {
@@ -363,6 +360,7 @@ static gboolean
 cut_test_case_run_tests (CutTestCase *test_case, CutRunner *runner,
                          const GList *tests)
 {
+    CutTestCasePrivate *priv;
     const GList *list;
     gboolean all_success = TRUE;
 
@@ -370,6 +368,12 @@ cut_test_case_run_tests (CutTestCase *test_case, CutRunner *runner,
     g_signal_emit_by_name(test_case, "ready", g_list_length((GList *)tests));
     g_signal_emit_by_name(CUT_TEST(test_case), "start");
 
+    priv = CUT_TEST_CASE_GET_PRIVATE(test_case);
+
+    if (priv->initialize) {
+        priv->initialize();
+    }
+
     for (list = tests; list; list = g_list_next(list)) {
         if (!list->data)
             continue;
@@ -394,6 +398,9 @@ cut_test_case_run_tests (CutTestCase *test_case, CutRunner *runner,
         g_object_unref(result);
     }
 
+    if (priv->finalize) {
+        priv->finalize();
+    }
     g_signal_emit_by_name(CUT_TEST(test_case), "complete");
 
     return all_success;
