@@ -35,6 +35,9 @@ G_BEGIN_DECLS
 #define CUT_IS_TEST_CASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CUT_TYPE_TEST_CASE))
 #define CUT_TEST_CASE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), CUT_TYPE_TEST_CASE, CutTestCaseClass))
 
+typedef void (*CutInitializeFunction) (void);
+typedef void (*CutFinalizeFunction)   (void);
+
 typedef struct _CutTestCaseClass CutTestCaseClass;
 
 struct _CutTestCase
@@ -64,7 +67,9 @@ CutTestCase *cut_test_case_new            (const gchar *name,
                                            CutGetCurrentTestContextFunction
                                            get_current_test_context_function,
                                            CutSetCurrentTestContextFunction
-                                           set_current_test_context_function);
+                                           set_current_test_context_function,
+                                           CutInitializeFunction initialize_function,
+                                           CutFinalizeFunction finalize_function);
 void         cut_test_case_add_test       (CutTestCase *test_case,
                                            CutTest *test);
 guint        cut_test_case_get_n_tests    (CutTestCase  *test_case,
