@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
@@ -41,6 +41,7 @@
 #include "cut-runner.h"
 #include "cut-utils.h"
 #include "cut-marshalers.h"
+#include "cut-test-result.h"
 
 #define CUT_TEST_SUITE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_TEST_SUITE, CutTestSuitePrivate))
 
@@ -361,8 +362,17 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
                 all_success = FALSE;
         }
 
-        if (all_success)
-            g_signal_emit_by_name(CUT_TEST(test_suite), "success");
+        if (all_success) {
+            CutTestResult *result;
+            result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
+                                         NULL,
+                                         NULL,
+                                         test_suite,
+                                         NULL, NULL, 
+                                         NULL, NULL, 0);
+            g_signal_emit_by_name(CUT_TEST(test_suite), "success", result);
+            g_object_unref(result);
+        }
         break;
       case SIGSEGV:
         all_success = FALSE;
