@@ -32,6 +32,7 @@
 #include <cutter/cut-module-impl.h>
 #include <cutter/cut-report.h>
 #include <cutter/cut-runner.h>
+#include <cutter/cut-test-result.h>
 #include <cutter/cut-enum-types.h>
 
 #define CUT_TYPE_REPORT_XML            cut_type_report_xml
@@ -74,12 +75,15 @@ static void get_property   (GObject         *object,
                             GValue          *value,
                             GParamSpec      *pspec);
 
-static void cut_report_xml_set_runner (CutReportXML *report,
-                                       CutRunner    *runner);
+static void attach_to_runner             (CutListener *listener,
+                                          CutRunner   *runner);
+static void detach_from_runner           (CutListener *listener,
+                                          CutRunner   *runner);
 
 static gboolean result_to_file           (CutReport        *report,
                                           const gchar      *filename,
                                           CutReportFileMode mode);
+static gchar   *get_result               (CutTestResult *result);
 static gchar   *get_all_results          (CutReport   *report);
 static gchar   *get_success_results      (CutReport   *report);
 static gchar   *get_error_results        (CutReport   *report);
@@ -94,17 +98,22 @@ class_init (CutReportXMLClass *klass)
 {
     GObjectClass *gobject_class;
     GParamSpec *spec;
+    CutListenerClass *listener_class;
     CutReportClass *report_class;
 
     parent_class = g_type_class_peek_parent(klass);
 
     gobject_class = G_OBJECT_CLASS(klass);
+    listener_class = CUT_LISTENER_CLASS(klass);
     report_class = CUT_REPORT_CLASS(klass);
 
     gobject_class->dispose      = dispose;
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
 
+    listener_class->attach_to_runner   = attach_to_runner;
+    listener_class->detach_from_runner = detach_from_runner;
+
     report_class->result_to_file           = result_to_file;
     report_class->get_all_results          = get_all_results;
     report_class->get_success_results      = get_success_results;
@@ -144,9 +153,6 @@ register_type (GTypeModule *type_module)
             (GInstanceInitFunc) init,
         };
 
-    if (g_type_from_name("CutReportXML"))
-        return;
-
     cut_type_report_xml =
         g_type_module_register_type(type_module,
                                     CUT_TYPE_REPORT,
@@ -190,7 +196,10 @@ dispose (GObject *object)
 {
     CutReportXML *report = CUT_REPORT_XML(object);
 
-    cut_report_xml_set_runner(report, NULL);
+    if (report->runner) {
+        g_object_unref(report->runner);
+        report->runner = NULL;
+    }
 
     G_OBJECT_CLASS(parent_class)->dispose(object);
 }
@@ -205,7 +214,7 @@ set_property (GObject      *object,
 
     switch (prop_id) {
       case PROP_RUNNER:
-        cut_report_xml_set_runner(report, CUT_RUNNER(g_value_get_object(value)));
+        attach_to_runner(CUT_LISTENER(report), CUT_RUNNER(g_value_get_object(value)));
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -250,43 +259,43 @@ cb_start_test (CutRunner *runner, CutTest *test, CutTestContext *test_context,
 }
 
 static void
-cb_success (CutRunner *runner, CutTest *test, CutReportXML *report)
+cb_success_test (CutRunner *runner, CutTest *test, CutReportXML *report)
 {
 }
 
 static void
-cb_failure (CutRunner       *runner,
-            CutTest          *test,
-            CutTestContext   *test_context,
-            CutTestResult    *result,
-            CutReportXML *report)
+cb_failure_test (CutRunner      *runner,
+                 CutTest        *test,
+                 CutTestContext *test_context,
+                 CutTestResult  *result,
+                 CutReportXML   *report)
 {
 }
 
 static void
-cb_error (CutRunner       *runner,
-          CutTest          *test,
-          CutTestContext   *test_context,
-          CutTestResult    *result,
-          CutReportXML *report)
+cb_error_test (CutRunner      *runner,
+               CutTest        *test,
+               CutTestContext *test_context,
+               CutTestResult  *result,
+               CutReportXML   *report)
 {
 }
 
 static void
-cb_pending (CutRunner       *runner,
-            CutTest          *test,
-            CutTestContext   *test_context,
-            CutTestResult    *result,
-            CutReportXML *report)
+cb_pending_test (CutRunner      *runner,
+                 CutTest        *test,
+                 CutTestContext *test_context,
+                 CutTestResult  *result,
+                 CutReportXML   *report)
 {
 }
 
 static void
-cb_notification (CutRunner       *runner,
-                 CutTest          *test,
-                 CutTestContext   *test_context,
-                 CutTestResult    *result,
-                 CutReportXML *report)
+cb_notification_test (CutRunner      *runner,
+                      CutTest        *test,
+                      CutTestContext *test_context,
+                      CutTestResult  *result,
+                      CutReportXML   *report)
 {
 }
 
@@ -324,11 +333,11 @@ connect_to_runner (CutReportXML *report, CutRunner *runner)
     CONNECT(start_test_case);
     CONNECT(start_test);
 
-    CONNECT(success);
-    CONNECT(failure);
-    CONNECT(error);
-    CONNECT(pending);
-    CONNECT(notification);
+    CONNECT(success_test);
+    CONNECT(failure_test);
+    CONNECT(error_test);
+    CONNECT(pending_test);
+    CONNECT(notification_test);
 
     CONNECT(complete_test);
     CONNECT(complete_test_case);
@@ -351,11 +360,11 @@ disconnect_from_runner (CutReportXML *report, CutRunner *runner)
     DISCONNECT(start_test_case);
     DISCONNECT(start_test);
 
-    DISCONNECT(success);
-    DISCONNECT(failure);
-    DISCONNECT(error);
-    DISCONNECT(pending);
-    DISCONNECT(notification);
+    DISCONNECT(success_test);
+    DISCONNECT(failure_test);
+    DISCONNECT(error_test);
+    DISCONNECT(pending_test);
+    DISCONNECT(notification_test);
 
     DISCONNECT(complete_test);
     DISCONNECT(complete_test_case);
@@ -367,20 +376,32 @@ disconnect_from_runner (CutReportXML *report, CutRunner *runner)
 }
 
 static void
-cut_report_xml_set_runner (CutReportXML *report, CutRunner *runner)
+attach_to_runner (CutListener *listener,
+                  CutRunner   *runner)
 {
-    if (report->runner) {
-        disconnect_from_runner(report, report->runner);
-        g_object_unref(report->runner);
-        report->runner = NULL;
-    }
-
+    CutReportXML *report = CUT_REPORT_XML(listener);
+    if (report->runner)
+        detach_from_runner(listener, report->runner);
+    
     if (runner) {
         report->runner = g_object_ref(runner);
-        connect_to_runner(report, runner);
+        connect_to_runner(CUT_REPORT_XML(listener), runner);
     }
 }
 
+static void
+detach_from_runner (CutListener *listener,
+                    CutRunner   *runner)
+{
+    CutReportXML *report = CUT_REPORT_XML(listener);
+    if (report->runner != runner)
+        return;
+
+    disconnect_from_runner(report, runner);
+    g_object_unref(report->runner);
+    report->runner = NULL;
+}
+
 static gboolean
 result_to_file (CutReport        *report,
                 const gchar      *filename,
@@ -451,7 +472,8 @@ append_element_valist (GString *string, guint indent, const gchar *element_name,
   
   	while (name) {
 		const gchar *value = va_arg(var_args, gchar*);
-        append_element_with_value(string, indent, name, value);
+        if (value)
+            append_element_with_value(string, indent, name, value);
 		name = va_arg(var_args, gchar*);
     }
 }
@@ -477,43 +499,99 @@ append_element_with_children (GString *string, guint indent, const gchar *elemen
 }
 
 static void
-/* append_test_case_info_to_string (GString *string, CutTestCase *test_case)*/
-append_test_case_info_to_string (GString *string, const gchar *test_case_name)
+append_attribute (const gchar *key, const gchar *value, GString *string)
 {
-    append_element_with_children(string, 4, "test_case",
-                                 "name", test_case_name,
+    guint indent = 6;
+
+    if (!strcmp(key, "description"))
+        return;
+
+    append_indent(string, indent);
+    g_string_append(string, "<option>\n");
+
+    append_element_with_value(string, indent + 2, "name", key);
+    append_element_with_value(string, indent + 2, "value", value);
+
+    append_indent(string, indent);
+    g_string_append(string, "</option>\n");
+}
+
+static void
+append_test_info_to_string (GString *string, const gchar *element_name, CutTest *test)
+{
+    gchar *escaped;
+    const gchar *description, *name;
+    guint indent = 4;
+    GHashTable *attributes;
+
+    escaped = g_markup_escape_text(element_name, -1);
+    append_indent(string, indent);
+    g_string_append_printf(string, "<%s>\n", escaped);
+
+    name = cut_test_get_name(test);
+    if (name)
+        append_element_with_value(string, indent + 2, "name", name);
+
+    description = cut_test_get_description(test);
+    if (description)
+        append_element_with_value(string, indent + 2, "description", description);
+
+    attributes = (GHashTable*)cut_test_get_attributes(test);
+    if (attributes)
+        g_hash_table_foreach(attributes, (GHFunc)append_attribute, string);
+
+    append_indent(string, indent);
+    g_string_append_printf(string, "</%s>\n", escaped);
+    g_free(escaped);
+}
+
+static void
+append_backtrace_to_string (GString *string, CutTestResult *result)
+{
+    gchar *line_string, *info_string;
+
+    line_string = g_strdup_printf("%d", cut_test_result_get_line(result));
+    info_string = g_strdup_printf("%s()", cut_test_result_get_function_name(result));
+
+    append_element_with_children(string, 4, "backtrace",
+                                 "file", cut_test_result_get_filename(result),
+                                 "line", line_string,
+                                 "info", info_string,
                                  NULL);
+    g_free(line_string);
+    g_free(info_string);
 }
 
 static void
 append_test_result_to_string (GString *string, CutTestResult *result)
 {
+    CutTestResultStatus status;
     gchar *elapsed_string;
-    elapsed_string = g_strdup_printf("%g", cut_test_result_get_elapsed(result));
-    append_element_with_children(string, 4, "result",
-                                 "status", result_status_to_name(cut_test_result_get_status(result)),
-                                 "detail", "",
-                                 "elapsed", elapsed_string,
-                                 NULL);
+    const gchar *message;
+
+    elapsed_string = g_strdup_printf("%f", cut_test_result_get_elapsed(result));
+    message = cut_test_result_get_message(result);
+    status = cut_test_result_get_status(result);
+
+    append_element_with_value(string, 4, "status", result_status_to_name(status));
+    if (message)
+        append_element_with_value(string, 4, "detail", message);
+    if (status != CUT_TEST_RESULT_SUCCESS)
+        append_backtrace_to_string(string, result);
+    append_element_with_value(string, 4, "elapsed", elapsed_string);
     g_free(elapsed_string);
 }
 
 static gchar *
 get_result (CutTestResult *result)
 {
-    CutTestResultStatus status;
     GString *xml = g_string_new("");
 
-    status = cut_test_result_get_status(result);
-
-    g_string_append(xml, "  <test_log>\n");
-    append_test_case_info_to_string(xml, 
-                                    cut_test_result_get_test_case_name(result));
-    append_element_with_value(xml, 4, "name", cut_test_result_get_test_name(result));
-    /* append_test_description_to_string(xml, cut_test_result_get_test_description(result)); */
-    /* append_test_metadata_to_string(xml, cut_test_result_get_test_metadata(result)); */
+    g_string_append(xml, "  <result>\n");
+    append_test_info_to_string(xml, "test-case", CUT_TEST(cut_test_result_get_test_case(result)));
+    append_test_info_to_string(xml, "test", cut_test_result_get_test(result));
     append_test_result_to_string(xml, result);
-    g_string_append(xml, "  </test_log>\n");
+    g_string_append(xml, "  </result>\n");
 
     return g_string_free(xml, FALSE);
 }
