@@ -32,6 +32,7 @@
 #include <cutter/cut-module-impl.h>
 #include <cutter/cut-ui.h>
 #include <cutter/cut-runner.h>
+#include <cutter/cut-test-result.h>
 #include <cutter/cut-test.h>
 #include <cutter/cut-test-suite.h>
 #include <cutter/cut-test-context.h>
@@ -93,26 +94,30 @@ static void get_property   (GObject         *object,
                             guint            prop_id,
                             GValue          *value,
                             GParamSpec      *pspec);
-static gboolean run        (CutUI    *ui,
-                            CutRunner   *runner);
+
+static void attach_to_runner   (CutListener *listener,
+                                CutRunner   *runner);
+static void detach_from_runner (CutListener *listener,
+                                CutRunner   *runner);
 
 static void
 class_init (CutUIClass *klass)
 {
     GObjectClass *gobject_class;
-    CutUIClass *ui_class;
+    CutListenerClass *listener_class;
     GParamSpec *spec;
 
     parent_class = g_type_class_peek_parent(klass);
 
     gobject_class = G_OBJECT_CLASS(klass);
-    ui_class  = CUT_UI_CLASS(klass);
+    listener_class = CUT_LISTENER_CLASS(klass);
 
     gobject_class->dispose      = dispose;
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
 
-    ui_class->run = run;
+    listener_class->attach_to_runner   = attach_to_runner;
+    listener_class->detach_from_runner = detach_from_runner;
 
     spec = g_param_spec_boolean("use-color",
                                 "Use color",
@@ -379,7 +384,7 @@ cb_start_test (CutRunner *runner, CutTest *test, CutTestContext *test_context,
 }
 
 static void
-cb_success (CutRunner *runner, CutTest *test, CutUIConsole *console)
+cb_success_test (CutRunner *runner, CutTest *test, CutUIConsole *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
@@ -390,11 +395,11 @@ cb_success (CutRunner *runner, CutTest *test, CutUIConsole *console)
 }
 
 static void
-cb_failure (CutRunner      *runner,
-            CutTest        *test,
-            CutTestContext *test_context,
-            CutTestResult  *result,
-            CutUIConsole   *console)
+cb_failure_test (CutRunner      *runner,
+                 CutTest        *test,
+                 CutTestContext *test_context,
+                 CutTestResult  *result,
+                 CutUIConsole   *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
@@ -403,11 +408,11 @@ cb_failure (CutRunner      *runner,
 }
 
 static void
-cb_error (CutRunner      *runner,
-          CutTest        *test,
-          CutTestContext *test_context,
-          CutTestResult  *result,
-          CutUIConsole   *console)
+cb_error_test (CutRunner      *runner,
+               CutTest        *test,
+               CutTestContext *test_context,
+               CutTestResult  *result,
+               CutUIConsole   *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
@@ -416,11 +421,11 @@ cb_error (CutRunner      *runner,
 }
 
 static void
-cb_pending (CutRunner      *runner,
-            CutTest        *test,
-            CutTestContext *test_context,
-            CutTestResult  *result,
-            CutUIConsole   *console)
+cb_pending_test (CutRunner      *runner,
+                 CutTest        *test,
+                 CutTestContext *test_context,
+                 CutTestResult  *result,
+                 CutUIConsole   *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
@@ -429,11 +434,11 @@ cb_pending (CutRunner      *runner,
 }
 
 static void
-cb_notification (CutRunner      *runner,
-                 CutTest        *test,
-                 CutTestContext *test_context,
-                 CutTestResult  *result,
-                 CutUIConsole   *console)
+cb_notification_test (CutRunner      *runner,
+                      CutTest        *test,
+                      CutTestContext *test_context,
+                      CutTestResult  *result,
+                      CutUIConsole   *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
@@ -505,20 +510,14 @@ print_results (CutUIConsole *console, CutRunner *runner)
         CutTest *test;
         gchar *filename;
         const gchar *message;
-        const gchar *source_directory;
         const gchar *name;
 
         status = cut_test_result_get_status(result);
         if (status == CUT_TEST_RESULT_SUCCESS)
             continue; 
 
-        source_directory = cut_runner_get_source_directory(runner);
-        if (source_directory)
-            filename = g_build_filename(source_directory,
-                                        cut_test_result_get_filename(result),
-                                        NULL);
-        else
-            filename = g_strdup(cut_test_result_get_filename(result));
+        filename = cut_runner_build_source_filename(runner,
+                                             cut_test_result_get_filename(result));
 
         message = cut_test_result_get_message(result);
         name = cut_test_result_get_test_name(result);
@@ -641,11 +640,11 @@ connect_to_runner (CutUIConsole *console, CutRunner *runner)
     CONNECT(start_test_case);
     CONNECT(start_test);
 
-    CONNECT(success);
-    CONNECT(failure);
-    CONNECT(error);
-    CONNECT(pending);
-    CONNECT(notification);
+    CONNECT(success_test);
+    CONNECT(failure_test);
+    CONNECT(error_test);
+    CONNECT(pending_test);
+    CONNECT(notification_test);
 
     CONNECT(complete_test);
     CONNECT(complete_test_case);
@@ -668,11 +667,11 @@ disconnect_from_runner (CutUIConsole *console, CutRunner *runner)
     DISCONNECT(start_test_case);
     DISCONNECT(start_test);
 
-    DISCONNECT(success);
-    DISCONNECT(failure);
-    DISCONNECT(error);
-    DISCONNECT(pending);
-    DISCONNECT(notification);
+    DISCONNECT(success_test);
+    DISCONNECT(failure_test);
+    DISCONNECT(error_test);
+    DISCONNECT(pending_test);
+    DISCONNECT(notification_test);
 
     DISCONNECT(complete_test);
     DISCONNECT(complete_test_case);
@@ -683,19 +682,19 @@ disconnect_from_runner (CutUIConsole *console, CutRunner *runner)
 #undef DISCONNECT
 }
 
-static gboolean
-run (CutUI *ui, CutRunner *runner)
+static void
+attach_to_runner (CutListener *listener,
+                  CutRunner   *runner)
 {
-    CutUIConsole *console = CUT_UI_CONSOLE(ui);
-    gboolean success;
-
-    connect_to_runner(console, runner);
-    success = cut_runner_run(runner);
-    disconnect_from_runner(console, runner);
-
-    return success;
+    connect_to_runner(CUT_UI_CONSOLE(listener), runner);
 }
 
+static void
+detach_from_runner (CutListener *listener,
+                    CutRunner   *runner)
+{
+    disconnect_from_runner(CUT_UI_CONSOLE(listener), runner);
+}
 
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
