@@ -35,6 +35,7 @@
 #include <cutter/cut-module-impl.h>
 #include <cutter/cut-ui.h>
 #include <cutter/cut-runner.h>
+#include <cutter/cut-test-result.h>
 #include <cutter/cut-test.h>
 #include <cutter/cut-test-case.h>
 #include <cutter/cut-verbose-level.h>
@@ -113,8 +114,10 @@ static void get_property   (GObject         *object,
                             guint            prop_id,
                             GValue          *value,
                             GParamSpec      *pspec);
-static gboolean run        (CutUI    *ui,
-                            CutRunner   *runner);
+static void attach_to_runner   (CutListener *listener,
+                                CutRunner   *runner);
+static void detach_from_runner (CutListener *listener,
+                                CutRunner   *runner);
 
 static gboolean idle_cb_run_test (gpointer data);
 
@@ -122,18 +125,19 @@ static void
 class_init (CutUIClass *klass)
 {
     GObjectClass *gobject_class;
-    CutUIClass *ui_class;
+    CutListenerClass *listener_class;
 
     parent_class = g_type_class_peek_parent(klass);
 
     gobject_class = G_OBJECT_CLASS(klass);
-    ui_class  = CUT_UI_CLASS(klass);
+    listener_class = CUT_LISTENER_CLASS(klass);
 
     gobject_class->dispose      = dispose;
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
 
-    ui_class->run           = run;
+    listener_class->attach_to_runner   = attach_to_runner;
+    listener_class->detach_from_runner = detach_from_runner;
 }
 
 static void
@@ -954,17 +958,11 @@ append_test_result_row (CutUIGtk *ui, CutTestResult *result,
     CutTestResultStatus status;
     gchar *filename, *name;
     const gchar *message;
-    const gchar *source_directory;
     const gchar *test_name;
     GdkPixbuf *icon;
 
-    source_directory = cut_runner_get_source_directory(ui->runner);
-    if (source_directory)
-        filename = g_build_filename(source_directory,
-                                    cut_test_result_get_filename(result),
-                                    NULL);
-    else
-        filename = g_strdup(cut_test_result_get_filename(result));
+    filename = cut_runner_build_source_filename(ui->runner, 
+                                                cut_test_result_get_filename(result));
     status = cut_test_result_get_status(result);
     message = cut_test_result_get_message(result);
     test_name = cut_test_result_get_test_name(result);
@@ -1418,22 +1416,26 @@ idle_cb_run_test (gpointer data)
     return FALSE;
 }
 
-static gboolean
-run (CutUI *ui, CutRunner *runner)
+static void
+attach_to_runner (CutListener *listener,
+                  CutRunner   *runner)
 {
-    CutUIGtk *gtk_ui;
+    CutUIGtk *gtk_ui = CUT_UI_GTK(listener);
 
-    gtk_ui = CUT_UI_GTK(ui);
     gtk_ui->test_suite = g_object_ref(cut_runner_get_test_suite(runner));
     gtk_ui->runner = g_object_ref(runner);
     gtk_widget_show_all(gtk_ui->window);
     g_idle_add(idle_cb_run_test, gtk_ui);
     gtk_main();
-
-    return gtk_ui->status <= CUT_TEST_RESULT_NOTIFICATION;
 }
 
+static void
+detach_from_runner (CutListener *listener,
+                    CutRunner   *runner)
+{
+    disconnect_from_runner(CUT_UI_GTK(listener), runner);
+}
 
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
