@@ -15,7 +15,7 @@ if test x"$CUTTER_DEBUG" = x"yes"; then
 fi
 
 export CUT_UI_MODULE_DIR=$BASE_DIR/../cutter/module/ui/.libs
-export CUT_UI_FACTORY_MODULE_DIR=$BASE_DIR/../cutter/module/ui-factory/.libs
+export CUT_FACTORY_MODULE_DIR=$BASE_DIR/../cutter/module/factory
 export CUT_REPORT_MODULE_DIR=$BASE_DIR/../cutter/module/report/.libs
 
 CUTTER_ARGS="--multi-thread -s $BASE_DIR"
