@@ -16,9 +16,7 @@ test_get_status (void)
     CutTestResult *result;
 
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -29,9 +27,7 @@ test_get_status (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -42,9 +38,7 @@ test_get_status (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_ERROR,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -55,9 +49,7 @@ test_get_status (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_PENDING,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -74,9 +66,7 @@ test_get_message_full (void)
     CutTestResult *result;
 
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -97,9 +87,7 @@ test_get_message_only_user (void)
     CutTestResult *result;
 
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  "user-message",
                                  NULL,
                                  "function-name",
@@ -119,9 +107,7 @@ test_get_message_only_system (void)
     CutTestResult *result;
 
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  NULL,
                                  "system-message",
                                  "function-name",
@@ -141,9 +127,7 @@ test_get_message_none (void)
     CutTestResult *result;
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  "function-name",
@@ -164,9 +148,7 @@ test_get_function_name (void)
     CutTestResult *result;
 
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -177,9 +159,7 @@ test_get_function_name (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  NULL,
@@ -196,9 +176,7 @@ test_get_filename (void)
     CutTestResult *result;
 
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -208,9 +186,7 @@ test_get_filename (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  NULL,
@@ -227,9 +203,7 @@ test_get_line (void)
     CutTestResult *result;
 
     result = cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  "user-message",
                                  "system-message",
                                  "function-name",
@@ -239,9 +213,7 @@ test_get_line (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  NULL,
@@ -251,9 +223,7 @@ test_get_line (void)
     g_object_unref(result);
 
     result = cut_test_result_new(CUT_TEST_RESULT_FAILURE,
-                                 "test-name",
-                                 "test-case-name",
-                                 "test-suite-name",
+                                 NULL, NULL, NULL,
                                  NULL,
                                  NULL,
                                  NULL,
